@@ -1,7 +1,7 @@
 package App::DateUtils;
 
-our $DATE = '2016-06-29'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2016-07-10'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -36,22 +36,41 @@ my %durations_arg = (
     },
 );
 
+my %all_modules_arg = (
+    all_modules => {
+        summary => 'Parse using all installed modules and '.
+            'return all the result at once',
+        schema => ['bool*', is=>1],
+        cmdline_aliases => {a=>{}},
+    },
+);
+
+my @parse_date_modules = (
+    'DateTime::Format::Alami::EN',
+    'DateTime::Format::Alami::ID',
+    'DateTime::Format::Flexible',
+    'DateTime::Format::Flexible(de)',
+    'DateTime::Format::Flexible(es)',
+    'DateTime::Format::Natural',
+);
+
+my @parse_duration_modules = (
+    'DateTime::Format::Alami::EN',
+    'DateTime::Format::Alami::ID',
+    'DateTime::Format::Natural',
+    'Time::Duration::Parse',
+);
+
 $SPEC{parse_date} = {
     v => 1.1,
     summary => 'Parse date string(s) using one of several modules',
     args => {
         module => {
-            schema  => ['str*', in=>[
-                'DateTime::Format::Alami::EN',
-                'DateTime::Format::Alami::ID',
-                'DateTime::Format::Flexible',
-                'DateTime::Format::Flexible(de)',
-                'DateTime::Format::Flexible(es)',
-                'DateTime::Format::Natural',
-            ]],
+            schema  => ['str*', in=>\@parse_date_modules],
             default => 'DateTime::Format::Flexible',
             cmdline_aliases => {m=>{}},
         },
+        %all_modules_arg,
         %time_zone_arg,
         %dates_arg,
     },
@@ -64,77 +83,104 @@ $SPEC{parse_date} = {
 sub parse_date {
     my %args = @_;
 
-    my $mod = $args{module};
-
-    my $parser;
-    if ($mod eq 'DateTime::Format::Alami::EN') {
-        require DateTime::Format::Alami::EN;
-        $parser = DateTime::Format::Alami::EN->new(
-            ( time_zone => $args{time_zone} ) x !!(defined($args{time_zone})),
-        );
-    } elsif ($mod eq 'DateTime::Format::Alami::ID') {
-        require DateTime::Format::Alami::ID;
-        $parser = DateTime::Format::Alami::ID->new(
-            ( time_zone => $args{time_zone} ) x !!(defined($args{time_zone})),
-        );
-    } elsif ($mod =~ /^DateTime::Format::Flexible/) {
-        require DateTime::Format::Flexible;
-        $parser = DateTime::Format::Flexible->new(
-        );
-    } elsif ($mod eq 'DateTime::Format::Natural') {
-        require DateTime::Format::Natural;
-        $parser = DateTime::Format::Natural->new(
-            ( time_zone => $args{time_zone} ) x !!(defined($args{time_zone})),
-        );
+    my %mods; # val = 1 if installed
+    if ($args{all_modules}) {
+        require Module::Path::More;
+        for my $mod0 (@parse_date_modules) {
+            (my $mod = $mod0) =~ s/\(.+//;
+            $mods{$mod0} = Module::Path::More::module_path(module => $mod) ?
+                1:0;
+        }
     } else {
-        return [400, "Unknown module '$mod'"];
+        %mods = ($args{module} => 1);
     }
 
     my @res;
-    for my $date (@{ $args{dates} }) {
-        my $rec = { original => $date };
-        if ($mod =~ /^DateTime::Format::Alami/) {
-            my $res = $parser->parse_datetime($date, {format=>'combined'});
-            if ($res->{DateTime}) {
-                $rec->{is_parseable} = 1;
-                $rec->{as_epoch} = $res->{epoch};
-                $rec->{as_datetime_obj} = "$res->{DateTime}";
-                $rec->{pattern} = $res->{pattern};
+    for my $mod (sort keys %mods) {
+        my $mod_is_installed = $mods{$mod};
+
+        my $parser;
+        if ($mod_is_installed) {
+            if ($mod eq 'DateTime::Format::Alami::EN') {
+                require DateTime::Format::Alami::EN;
+                $parser = DateTime::Format::Alami::EN->new(
+                    ( time_zone => $args{time_zone} ) x
+                        !!(defined($args{time_zone})),
+                );
+            } elsif ($mod eq 'DateTime::Format::Alami::ID') {
+                require DateTime::Format::Alami::ID;
+                $parser = DateTime::Format::Alami::ID->new(
+                    ( time_zone => $args{time_zone} ) x
+                        !!(defined($args{time_zone})),
+                );
+            } elsif ($mod =~ /^DateTime::Format::Flexible/) {
+                require DateTime::Format::Flexible;
+                $parser = DateTime::Format::Flexible->new(
+                );
+            } elsif ($mod eq 'DateTime::Format::Natural') {
+                require DateTime::Format::Natural;
+                $parser = DateTime::Format::Natural->new(
+                    ( time_zone => $args{time_zone} ) x
+                        !!(defined($args{time_zone})),
+                );
             } else {
-                $rec->{is_parseable} = 0;
-            }
-        } elsif ($mod =~ /^DateTime::Format::Flexible/) {
-            my $dt;
-            my %opts;
-            $opts{lang} = [$1] if $mod =~ /\((\w+)\)$/;
-            eval { $dt = $parser->parse_datetime(
-                $date,
-                %opts,
-            ) };
-            my $err = $@;
-            if (!$err) {
-                $rec->{is_parseable} = 1;
-                $rec->{as_epoch} = $dt->epoch;
-                $rec->{as_datetime_obj} = "$dt";
-            } else {
-                $err =~ s/\n/ /g;
-                $rec->{is_parseable} = 0;
-                $rec->{error_msg} = $err;
-            }
-        } elsif ($mod =~ /^DateTime::Format::Natural/) {
-            my $dt = $parser->parse_datetime($date);
-            if ($parser->success) {
-                $rec->{is_parseable} = 1;
-                $rec->{as_epoch} = $dt->epoch;
-                $rec->{as_datetime_obj} = "$dt";
-            } else {
-                $rec->{is_parseable} = 0;
-                $rec->{error_msg} = $parser->error;
+                return [400, "Unknown module '$mod'"];
             }
         }
-        push @res, $rec;
-    }
-    [200, "OK", \@res];
+
+      DATE:
+        for my $date (@{ $args{dates} }) {
+            my $rec = { original => $date, module => $mod };
+            unless ($mod_is_installed) {
+                $rec->{error_msg} = "module not installed";
+                goto PUSH_RESULT;
+            }
+            if ($mod =~ /^DateTime::Format::Alami/) {
+                my $res;
+                eval { $parser->parse_datetime($date, {format=>'combined'}) };
+                if ($@) {
+                    $rec->{is_parseable} = 0;
+                } else {
+                    $rec->{is_parseable} = 1;
+                    $rec->{as_epoch} = $res->{epoch};
+                    $rec->{as_datetime_obj} = "$res->{DateTime}";
+                    $rec->{pattern} = $res->{pattern};
+                }
+            } elsif ($mod =~ /^DateTime::Format::Flexible/) {
+                my $dt;
+                my %opts;
+                $opts{lang} = [$1] if $mod =~ /\((\w+)\)$/;
+                eval { $dt = $parser->parse_datetime(
+                    $date,
+                    %opts,
+                ) };
+                my $err = $@;
+                if (!$err) {
+                    $rec->{is_parseable} = 1;
+                    $rec->{as_epoch} = $dt->epoch;
+                    $rec->{as_datetime_obj} = "$dt";
+                } else {
+                    $err =~ s/\n/ /g;
+                    $rec->{is_parseable} = 0;
+                    $rec->{error_msg} = $err;
+                }
+            } elsif ($mod =~ /^DateTime::Format::Natural/) {
+                my $dt = $parser->parse_datetime($date);
+                if ($parser->success) {
+                    $rec->{is_parseable} = 1;
+                    $rec->{as_epoch} = $dt->epoch;
+                    $rec->{as_datetime_obj} = "$dt";
+                } else {
+                    $rec->{is_parseable} = 0;
+                    $rec->{error_msg} = $parser->error;
+                }
+            }
+          PUSH_RESULT:
+            push @res, $rec;
+        } # for dates
+    } # for mods
+
+    [200, "OK", \@res, {'table.fields'=>[qw/module original is_parseable as_epoch as_datetime_obj error_msg/]}];
 }
 
 $SPEC{parse_date_using_df_flexible} = {
@@ -222,89 +268,109 @@ $SPEC{parse_duration} = {
     summary => 'Parse duration string(s) using one of several modules',
     args => {
         module => {
-            schema  => ['str*', in=>[
-                'DateTime::Format::Alami::EN',
-                'DateTime::Format::Alami::ID',
-                'DateTime::Format::Natural',
-                'Time::Duration::Parse',
-            ]],
+            schema  => ['str*', in=>\@parse_duration_modules],
             default => 'Time::Duration::Parse',
             cmdline_aliases => {m=>{}},
         },
         %durations_arg,
+        %all_modules_arg,
     },
 };
 sub parse_duration {
     my %args = @_;
 
-    my $mod = $args{module};
-
-    my $parser;
-    if ($mod eq 'DateTime::Format::Alami::EN') {
-        require DateTime::Format::Alami::EN;
-        $parser = DateTime::Format::Alami::EN->new();
-    } elsif ($mod eq 'DateTime::Format::Alami::ID') {
-        require DateTime::Format::Alami::ID;
-        $parser = DateTime::Format::Alami::ID->new();
-    } elsif ($mod eq 'DateTime::Format::Natural') {
-        require DateTime::Format::Natural;
-        $parser = DateTime::Format::Natural->new();
-    } elsif ($mod eq 'Time::Duration::Parse') {
-        require Time::Duration::Parse;
+    my %mods; # val = 1 if installed
+    if ($args{all_modules}) {
+        require Module::Path::More;
+        for my $mod0 (@parse_duration_modules) {
+            (my $mod = $mod0) =~ s/\(.+//;
+            $mods{$mod0} = Module::Path::More::module_path(module => $mod) ?
+                1:0;
+        }
+    } else {
+        %mods = ($args{module} => 1);
     }
 
     my @res;
-    for my $dur (@{ $args{durations} }) {
-        my $rec = { original => $dur };
-        if ($mod =~ /^DateTime::Format::Alami/) {
-            my $res = $parser->parse_datetime_duration($dur, {format=>'combined'});
-            if ($res) {
-                require DateTime::Format::Duration::ISO8601;
-                my $dtdurf = DateTime::Format::Duration::ISO8601->new;
-                $rec->{is_parseable} = 1;
-                $rec->{as_dtdur_obj} = $dtdurf->format_duration($res->{Duration});
-                $rec->{as_secs} = $res->{seconds};
-            } else {
-                $rec->{is_parseable} = 0;
-            }
-        } elsif ($mod =~ /^DateTime::Format::Natural/) {
-            my @dt = $parser->parse_datetime_duration($dur);
-            if (@dt > 1) {
-                require DateTime::Format::Duration::ISO8601;
-                my $dtdurf = DateTime::Format::Duration::ISO8601->new;
-                my $dtdur = $dt[1]->subtract_datetime($dt[0]);
-                $rec->{is_parseable} = 1;
-                $rec->{date1} = "$dt[0]";
-                $rec->{date2} = "$dt[1]";
-                $rec->{as_dtdur_obj} = $dtdurf->format_duration($dtdur);
-                $rec->{as_secs} =
-                    $dtdur->years * 365.25*86400 +
-                    $dtdur->months * 30.4375*86400 +
-                    $dtdur->weeks * 7*86400 +
-                    $dtdur->days * 86400 +
-                    $dtdur->hours * 3600 +
-                    $dtdur->minutes * 60 +
-                    $dtdur->seconds +
-                    $dtdur->nanoseconds * 1e-9;
-            } else {
-                $rec->{is_parseable} = 0;
-                $rec->{error_msg} = $parser->error;
-            }
-        } elsif ($mod eq 'Time::Duration::Parse') {
-            my $secs;
-            eval { $secs = Time::Duration::Parse::parse_duration($dur) };
-            if ($@) {
-                $rec->{is_parseable} = 0;
-                $rec->{error_msg} = $@;
-                $rec->{error_msg} =~ s/\n+/ /g;
-            } else {
-                $rec->{is_parseable} = 1;
-                $rec->{as_secs} = $secs;
+    for my $mod (sort keys %mods) {
+        my $mod_is_installed = $mods{$mod};
+
+        my $parser;
+        if ($mod_is_installed) {
+            if ($mod eq 'DateTime::Format::Alami::EN') {
+                require DateTime::Format::Alami::EN;
+                $parser = DateTime::Format::Alami::EN->new();
+            } elsif ($mod eq 'DateTime::Format::Alami::ID') {
+                require DateTime::Format::Alami::ID;
+                $parser = DateTime::Format::Alami::ID->new();
+            } elsif ($mod eq 'DateTime::Format::Natural') {
+                require DateTime::Format::Natural;
+                $parser = DateTime::Format::Natural->new();
+            } elsif ($mod eq 'Time::Duration::Parse') {
+                require Time::Duration::Parse;
             }
         }
-        push @res, $rec;
-    }
-    [200, "OK", \@res];
+
+      DURATION:
+        for my $dur (@{ $args{durations} }) {
+            my $rec = { original => $dur, module => $mod };
+            unless ($mod_is_installed) {
+                $rec->{error_msg} = "module not installed";
+                goto PUSH_RESULT;
+            }
+            if ($mod =~ /^DateTime::Format::Alami/) {
+                my $res;
+                eval { $res = $parser->parse_datetime_duration($dur, {format=>'combined'}) };
+                if ($@) {
+                    $rec->{is_parseable} = 0;
+                } else {
+                    require DateTime::Format::Duration::ISO8601;
+                    my $dtdurf = DateTime::Format::Duration::ISO8601->new;
+                    $rec->{is_parseable} = 1;
+                    $rec->{as_dtdur_obj} = $dtdurf->format_duration($res->{Duration});
+                    $rec->{as_secs} = $res->{seconds};
+                }
+            } elsif ($mod =~ /^DateTime::Format::Natural/) {
+                my @dt = $parser->parse_datetime_duration($dur);
+                if (@dt > 1) {
+                    require DateTime::Format::Duration::ISO8601;
+                    my $dtdurf = DateTime::Format::Duration::ISO8601->new;
+                    my $dtdur = $dt[1]->subtract_datetime($dt[0]);
+                    $rec->{is_parseable} = 1;
+                    $rec->{date1} = "$dt[0]";
+                    $rec->{date2} = "$dt[1]";
+                    $rec->{as_dtdur_obj} = $dtdurf->format_duration($dtdur);
+                    $rec->{as_secs} =
+                        $dtdur->years * 365.25*86400 +
+                        $dtdur->months * 30.4375*86400 +
+                        $dtdur->weeks * 7*86400 +
+                        $dtdur->days * 86400 +
+                        $dtdur->hours * 3600 +
+                        $dtdur->minutes * 60 +
+                        $dtdur->seconds +
+                        $dtdur->nanoseconds * 1e-9;
+                } else {
+                    $rec->{is_parseable} = 0;
+                    $rec->{error_msg} = $parser->error;
+                }
+            } elsif ($mod eq 'Time::Duration::Parse') {
+                my $secs;
+                eval { $secs = Time::Duration::Parse::parse_duration($dur) };
+                if ($@) {
+                    $rec->{is_parseable} = 0;
+                    $rec->{error_msg} = $@;
+                    $rec->{error_msg} =~ s/\n+/ /g;
+                } else {
+                    $rec->{is_parseable} = 1;
+                    $rec->{as_secs} = $secs;
+                }
+            }
+          PUSH_RESULT:
+            push @res, $rec;
+        } # for durations
+    } # for modules
+
+    [200, "OK", \@res, {'table.fields'=>[qw/module original is_parseable as_secs as_dtdur_obj error_msg/]}];
 }
 
 $SPEC{parse_duration_using_df_alami_en} = {
@@ -494,7 +560,7 @@ App::DateUtils - An assortment of date-/time-related CLI utilities
 
 =head1 VERSION
 
-This document describes version 0.09 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-06-29.
+This document describes version 0.10 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-07-10.
 
 =head1 SYNOPSIS
 
@@ -542,7 +608,7 @@ Examples:
 
 =item * Convert "today" to epoch:
 
- dateconv(date => "today"); # -> 1467158400
+ dateconv(date => "today"); # -> 1468108800
 
 =item * Convert epoch to ymd:
 
@@ -613,24 +679,36 @@ Result:
    "OK",
    [
      {
-       as_datetime_obj => "2015-09-23T00:00:00",
-       as_epoch        => 1442966400,
-       is_parseable    => 1,
+       module          => "DateTime::Format::Flexible",
        original        => "23 sep 2015",
-     },
-     {
-       as_datetime_obj => "2016-06-30T00:00:00",
-       as_epoch        => 1467244800,
        is_parseable    => 1,
-       original        => "tomorrow",
+       as_epoch        => 1442966400,
+       as_datetime_obj => "2015-09-23T00:00:00",
      },
      {
-       error_msg    => "Invalid date format: foo at /home/s1/perl5/perlbrew/perls/perl-5.22.1/lib/site_perl/5.22.1/Perinci/Access.pm line 81. ",
-       is_parseable => 0,
+       module          => "DateTime::Format::Flexible",
+       original        => "tomorrow",
+       is_parseable    => 1,
+       as_epoch        => 1468195200,
+       as_datetime_obj => "2016-07-11T00:00:00",
+     },
+     {
+       module       => "DateTime::Format::Flexible",
        original     => "foo",
+       is_parseable => 0,
+       error_msg    => "Invalid date format: foo at /home/s1/perl5/perlbrew/perls/perl-5.22.2/lib/site_perl/5.22.2/Perinci/Access.pm line 81. ",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_epoch",
+       "as_datetime_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =back
@@ -641,6 +719,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all_modules> => I<bool>
+
+Parse using all installed modules and return all the result at once.
+
 =item * B<dates>* => I<array[str]>
 
 =item * B<module> => I<str> (default: "DateTime::Format::Flexible")
@@ -680,19 +762,53 @@ Result:
    "OK",
    [
      {
-       as_datetime_obj => "2016-05-23T00:00:00",
-       as_epoch        => 1463961600,
-       is_parseable    => 1,
+       module          => "DateTime::Format::Alami::EN",
        original        => "23 May",
-       pattern         => "p_dateymd",
+       is_parseable    => 1,
+       as_epoch        => undef,
+       as_datetime_obj => "",
+       pattern         => undef,
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_epoch",
+       "as_datetime_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =item * Example #2:
 
- parse_date_using_df_alami_en(dates => ["foo"]); # -> [200, "OK", [{ is_parseable => 0, original => "foo" }], {}]
+ parse_date_using_df_alami_en(dates => ["foo"]);
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     {
+       module => "DateTime::Format::Alami::EN",
+       original => "foo",
+       is_parseable => 0,
+     },
+   ],
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_epoch",
+       "as_datetime_obj",
+       "error_msg",
+     ],
+   },
+ ]
 
 =back
 
@@ -734,11 +850,58 @@ Examples:
 
 Result:
 
- [200, "OK", [{ is_parseable => 0, original => "23 Mei" }], {}]
+ [
+   200,
+   "OK",
+   [
+     {
+       module          => "DateTime::Format::Alami::ID",
+       original        => "23 Mei",
+       is_parseable    => 1,
+       as_epoch        => undef,
+       as_datetime_obj => "",
+       pattern         => undef,
+     },
+   ],
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_epoch",
+       "as_datetime_obj",
+       "error_msg",
+     ],
+   },
+ ]
 
 =item * Example #2:
 
- parse_date_using_df_alami_id(dates => ["foo"]); # -> [200, "OK", [{ is_parseable => 0, original => "foo" }], {}]
+ parse_date_using_df_alami_id(dates => ["foo"]);
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     {
+       module => "DateTime::Format::Alami::ID",
+       original => "foo",
+       is_parseable => 0,
+     },
+   ],
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_epoch",
+       "as_datetime_obj",
+       "error_msg",
+     ],
+   },
+ ]
 
 =back
 
@@ -785,13 +948,23 @@ Result:
    "OK",
    [
      {
-       as_datetime_obj => "2016-06-23T00:00:00",
-       as_epoch        => 1466640000,
-       is_parseable    => 1,
+       module          => "DateTime::Format::Flexible",
        original        => "23rd Jun",
+       is_parseable    => 1,
+       as_epoch        => 1466640000,
+       as_datetime_obj => "2016-06-23T00:00:00",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_epoch",
+       "as_datetime_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =item * Example #2:
@@ -805,13 +978,23 @@ Result:
    "OK",
    [
      {
-       as_datetime_obj => "2016-12-23T00:00:00",
-       as_epoch        => 1482451200,
-       is_parseable    => 1,
+       module          => "DateTime::Format::Flexible(de)",
        original        => "23 Dez",
+       is_parseable    => 1,
+       as_epoch        => 1482451200,
+       as_datetime_obj => "2016-12-23T00:00:00",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_epoch",
+       "as_datetime_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =item * Example #3:
@@ -825,12 +1008,22 @@ Result:
    "OK",
    [
      {
-       error_msg    => "Invalid date format: foo at /home/s1/perl5/perlbrew/perls/perl-5.22.1/lib/site_perl/5.22.1/Perinci/Access.pm line 81. ",
-       is_parseable => 0,
+       module       => "DateTime::Format::Flexible",
        original     => "foo",
+       is_parseable => 0,
+       error_msg    => "Invalid date format: foo at /home/s1/perl5/perlbrew/perls/perl-5.22.2/lib/site_perl/5.22.2/Perinci/Access.pm line 81. ",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_epoch",
+       "as_datetime_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =back
@@ -880,13 +1073,23 @@ Result:
    "OK",
    [
      {
-       as_datetime_obj => "2016-06-23T00:00:00",
-       as_epoch        => 1466640000,
-       is_parseable    => 1,
+       module          => "DateTime::Format::Natural",
        original        => "23rd Jun",
+       is_parseable    => 1,
+       as_epoch        => 1466640000,
+       as_datetime_obj => "2016-06-23T00:00:00",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_epoch",
+       "as_datetime_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =item * Example #2:
@@ -900,12 +1103,22 @@ Result:
    "OK",
    [
      {
-       error_msg    => "'foo' does not parse (perhaps you have some garbage?)",
-       is_parseable => 0,
+       module       => "DateTime::Format::Natural",
        original     => "foo",
+       is_parseable => 0,
+       error_msg    => "'foo' does not parse (perhaps you have some garbage?)",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_epoch",
+       "as_datetime_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =back
@@ -944,6 +1157,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all_modules> => I<bool>
+
+Parse using all installed modules and return all the result at once.
+
 =item * B<durations>* => I<array[str]>
 
 =item * B<module> => I<str> (default: "Time::Duration::Parse")
@@ -981,18 +1198,52 @@ Result:
    "OK",
    [
      {
-       as_dtdur_obj => "PT2H3M",
-       as_secs      => 7380,
-       is_parseable => 1,
+       module       => "DateTime::Format::Alami::EN",
        original     => "2h, 3mins",
+       is_parseable => 1,
+       as_secs      => 7380,
+       as_dtdur_obj => "PT2H3M",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_secs",
+       "as_dtdur_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =item * Example #2:
 
- parse_duration_using_df_alami_en(durations => ["foo"]); # -> [200, "OK", [{ is_parseable => 0, original => "foo" }], {}]
+ parse_duration_using_df_alami_en(durations => ["foo"]);
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     {
+       module => "DateTime::Format::Alami::EN",
+       original => "foo",
+       is_parseable => 0,
+     },
+   ],
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_secs",
+       "as_dtdur_obj",
+       "error_msg",
+     ],
+   },
+ ]
 
 =back
 
@@ -1032,11 +1283,57 @@ Examples:
 
 Result:
 
- [200, "OK", [{ is_parseable => 0, original => "2j, 3mnt" }], {}]
+ [
+   200,
+   "OK",
+   [
+     {
+       module       => "DateTime::Format::Alami::ID",
+       original     => "2j, 3mnt",
+       is_parseable => 1,
+       as_secs      => 7380,
+       as_dtdur_obj => "PT2H3M",
+     },
+   ],
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_secs",
+       "as_dtdur_obj",
+       "error_msg",
+     ],
+   },
+ ]
 
 =item * Example #2:
 
- parse_duration_using_df_alami_id(durations => ["foo"]); # -> [200, "OK", [{ is_parseable => 0, original => "foo" }], {}]
+ parse_duration_using_df_alami_id(durations => ["foo"]);
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     {
+       module => "DateTime::Format::Alami::ID",
+       original => "foo",
+       is_parseable => 0,
+     },
+   ],
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_secs",
+       "as_dtdur_obj",
+       "error_msg",
+     ],
+   },
+ ]
 
 =back
 
@@ -1081,15 +1378,25 @@ Result:
    "OK",
    [
      {
-       as_dtdur_obj => "P2W",
-       as_secs => 1209600,
-       date1 => "2016-06-29T13:56:29",
-       date2 => "2016-07-13T13:56:29",
-       is_parseable => 1,
+       module => "DateTime::Format::Natural",
        original => "for 2 weeks",
+       is_parseable => 1,
+       as_secs => 1209600,
+       as_dtdur_obj => "P2W",
+       date2 => "2016-07-24T05:38:44",
+       date1 => "2016-07-10T05:38:44",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_secs",
+       "as_dtdur_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =item * Example #2:
@@ -1103,15 +1410,25 @@ Result:
    "OK",
    [
      {
-       as_dtdur_obj => "PT13H56M29S",
-       as_secs => 50189,
-       date1 => "2016-06-29T13:56:29",
-       date2 => "2016-06-29T00:00:00",
-       is_parseable => 1,
+       module => "DateTime::Format::Natural",
        original => "from 23 Jun to 29 Jun",
+       is_parseable => 1,
+       as_secs => 970724,
+       as_dtdur_obj => "P1W4DT5H38M44S",
+       date1 => "2016-07-10T05:38:44",
+       date2 => "2016-06-29T00:00:00",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_secs",
+       "as_dtdur_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =item * Example #3:
@@ -1125,12 +1442,22 @@ Result:
    "OK",
    [
      {
-       error_msg    => "'foo' does not parse (perhaps you have some garbage?)",
-       is_parseable => 0,
+       module       => "DateTime::Format::Natural",
        original     => "foo",
+       is_parseable => 0,
+       error_msg    => "'foo' does not parse (perhaps you have some garbage?)",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_secs",
+       "as_dtdur_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =back
@@ -1175,9 +1502,23 @@ Result:
    200,
    "OK",
    [
-     { as_secs => 219600, is_parseable => 1, original => "2 days 13 hours" },
+     {
+       module       => "Time::Duration::Parse",
+       original     => "2 days 13 hours",
+       is_parseable => 1,
+       as_secs      => 219600,
+     },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_secs",
+       "as_dtdur_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =item * Example #2:
@@ -1191,12 +1532,22 @@ Result:
    "OK",
    [
      {
-       error_msg    => "Unknown timespec: foo at lib/App/DateUtils.pm line 295. ",
-       is_parseable => 0,
+       module       => "Time::Duration::Parse",
        original     => "foo",
+       is_parseable => 0,
+       error_msg    => "Unknown timespec: foo at lib/App/DateUtils.pm line 358. ",
      },
    ],
-   {},
+   {
+     "table.fields" => [
+       "module",
+       "original",
+       "is_parseable",
+       "as_secs",
+       "as_dtdur_obj",
+       "error_msg",
+     ],
+   },
  ]
 
 =back
